@@ -53,7 +53,7 @@ class Informat:
     )
 
     #    char8 niform;      /* NAME OF INPUT FORMAT                   */
-    #    short nifl;         /* INFORMAT LENGTH ATTRIBUTE              */
+    #    short nifl;        /* INFORMAT LENGTH ATTRIBUTE              */
     #    short nifd;        /* INFORMAT NUMBER OF DECIMALS            */
     byte_structure = '>8shh'
 
@@ -271,7 +271,7 @@ class Variable(pd.Series):
     def __repr__(self):
         """REPL-format."""
         metadata = (name.strip('_') for name in self._metadata)
-        metadata = {name: getattr(self, name) for name in metadata}
+        metadata = {name: getattr(self, name, None) for name in metadata}
         metadata = (f'{name}: {value}' for name, value in metadata.items() if value is not None)
         return f'{type(self).__name__}\n{super().__repr__()}\n{", ".join(metadata)}'
 
@@ -293,6 +293,7 @@ class Variable(pd.Series):
         """
         Initialize SAS variable metadata.
         """
+        # TODO: Consider validating that the name isn't blank.
         metadata = {
             'label': label,
             'vtype': vtype,
@@ -337,7 +338,7 @@ class Variable(pd.Series):
 
         For example, transforming a series into a dataframe.
         """
-        raise NotImplementedError("Can't copy SAS variable metadata to dataframe")
+        return pd.DataFrame
 
     @property
     def format(self):
@@ -391,13 +392,12 @@ class Dataset(pd.DataFrame):
 
     _metadata = [
         'name',
-        'label',
+        'dataset_label',
         'dataset_type',
         'created',
         'modified',
         'sas_os',
         'sas_version',
-        # TODO: Consider including dataset type: {'DATA', 'VIEW', ''}.
     ]
 
     def copy_metadata(self, other):
@@ -418,7 +418,7 @@ class Dataset(pd.DataFrame):
     def __repr__(self):
         """REPL-format."""
         metadata = (name.strip('_') for name in self._metadata)
-        metadata = {name: getattr(self, name) for name in metadata}
+        metadata = {name: getattr(self, name, None) for name in metadata}
         metadata = (f'{name}: {value}' for name, value in metadata.items() if value)
         template = '''\
             {cls} {name}
@@ -443,7 +443,7 @@ class Dataset(pd.DataFrame):
         dtype=None,
         copy=False,
         name=None,
-        label=None,
+        dataset_label=None,
         dataset_type=None,
         created=None,
         modified=None,
@@ -454,9 +454,12 @@ class Dataset(pd.DataFrame):
         """
         Initialize SAS dataset metadata.
         """
+        # TODO: Consider validating dataset type: {'DATA', 'VIEW', 'CATALOG'}.
+        #       I think only 'DATA' is supported by the XPORT format.
+        # TODO: Consider validating that the name isn't blank.
         metadata = {
             'name': name,
-            'label': label,
+            'dataset_label': dataset_label,
             'created': created,
             'modified': modified,
             'sas_os': sas_os,
