@@ -286,7 +286,7 @@ class MemberHeader(Mapping):
     def __init__(
         self,
         name,
-        label,
+        dataset_label,
         dataset_type,
         created,
         modified,
@@ -298,7 +298,7 @@ class MemberHeader(Mapping):
         Initialize a ``MemberHeader``.
         """
         self.name = name
-        self.label = label
+        self.dataset_label = dataset_label
         self.dataset_type = dataset_type
         self.created = created
         self.modified = modified
@@ -358,7 +358,7 @@ class MemberHeader(Mapping):
             namestrs.append(ns)
         return cls(
             name=dataset.name,
-            label=dataset.label,
+            dataset_label=dataset.dataset_label,
             dataset_type=dataset.dataset_type,
             created=dataset.created,
             modified=dataset.modified,
@@ -368,12 +368,12 @@ class MemberHeader(Mapping):
         )
 
     @classmethod
-    def from_bytes(cls, bytestring: bytes):
+    def from_bytes(cls, bytestring: bytes, Namestr=Namestr):
         """
         Construct a ``MemberHeader`` from an XPORT-format byte string.
         """
         LOG.debug(f'Decode {type(cls).__name__}')
-        mo = cls.pattern.search(bytestring)
+        mo = cls.pattern.search(bytestring)  # TODO: Why ``search``, not ``match``?
         if mo is None:
             raise ValueError('No member header found')
 
@@ -390,7 +390,7 @@ class MemberHeader(Mapping):
             raise ValueError(f'Expected {n}, got {len(namestrs)}')
         self = cls(
             name=mo['name'].strip(b'\x00').decode('ISO-8859-1').strip(),
-            label=mo['label'].strip(b'\x00').decode('ISO-8859-1').strip(),
+            dataset_label=mo['label'].strip(b'\x00').decode('ISO-8859-1').strip(),
             dataset_type=mo['type'].strip(b'\x00').decode('ISO-8859-1').strip(),
             sas_os=mo['os'].strip(b'\x00').decode('ISO-8859-1').strip(),
             sas_version=mo['version'].strip().decode('ISO-8859-1'),
@@ -413,7 +413,7 @@ HEADER RECORD{'*' * 7}OBS     HEADER RECORD{'!' * 7}{'0' * 30}  \
 
     def __bytes__(self):
         """
-        Encode in XPORT-format.
+        Encode in XPORT format.
         """
         LOG.debug(f'Encode {type(self).__name__}')
         namestrs = b''.join(bytes(ns) for ns in self.values())
@@ -421,7 +421,7 @@ HEADER RECORD{'*' * 7}OBS     HEADER RECORD{'!' * 7}{'0' * 30}  \
             namestrs += b' ' * (80 - len(namestrs) % 80)
         return self.template % {
             b'name': text_encode(self, 'name', 8),
-            b'label': text_encode(self, 'label', 40),
+            b'label': text_encode(self, 'dataset_label', 40),
             b'type': text_encode(self, 'dataset_type', 8),
             b'n_variables': len(self),
             b'os': text_encode(self, 'sas_os', 8),
@@ -500,6 +500,8 @@ class Observations(Iterator):
             for i in range(0, len(mview), stride):
                 chunk = mview[i:i + stride]
                 if len(chunk) != stride or chunk == sentinel:
+                    # TODO: Why exit early if we know the size of the dataset?
+                    #       SAS mentions some software pads with nulls.
                     return
                 # TODO: If only characters and the last row is all empty
                 #       or spaces, it's indistinguishable from padding.
@@ -576,13 +578,13 @@ class Member(xport.Dataset):
         return self
 
     @classmethod
-    def from_bytes(cls, bytestring, pattern=MemberHeader.pattern):
+    def from_bytes(cls, bytestring, MemberHeader=MemberHeader, Observations=Observations):
         """
         Decode the first ``Member`` from an XPORT-format byte string.
         """
         LOG.debug(f'Decode {type(cls).__name__}')
         mview = memoryview(bytestring)
-        matches = pattern.finditer(mview)
+        matches = MemberHeader.pattern.finditer(mview)
 
         try:
             mo = next(matches)
@@ -597,8 +599,8 @@ class Member(xport.Dataset):
         else:
             j = mo.start(0)
 
-        header = xport.v56.MemberHeader.from_bytes(mview[:i])
-        observations = xport.v56.Observations.from_bytes(mview[i:j], header)
+        header = MemberHeader.from_bytes(mview[:i])
+        observations = Observations.from_bytes(mview[i:j], header)
 
         # This awkwardness works around Pandas subclasses misbehaving.
         # ``DataFrame.append`` discards subclass attributes.  Lame.
@@ -628,13 +630,17 @@ class Member(xport.Dataset):
                 continue
         if conversions:
             warnings.warn(f'Converting column dtypes {conversions}')
-            self = self.copy()  # Don't mutate!
+            # BUG: ``DataFrame.copy`` mutates and discards ``Variable`` metadata.
+            # self = self.copy()  # Don't mutate!
+            cpy = xport.Dataset({k: v for k, v in self.items()})
             for column, dtype in conversions.items():
                 LOG.warning(f'Converting column {column!r} from {dtypes[column]} to {dtype}')
                 try:
-                    self[column] = self[column].astype(dtype)
+                    cpy[column] = cpy[column].astype(dtype)
                 except Exception:
                     raise TypeError(f'Could not coerce column {column!r} to {dtype}')
+            cpy.copy_metadata(self)
+            self = cpy
         header = bytes(MemberHeader.from_dataset(self))
         observations = bytes(Observations.from_dataset(self))
         return header + observations
@@ -682,7 +688,7 @@ class Library(xport.Library):
     )
 
     @classmethod
-    def from_bytes(cls, bytestring, member_header_re=MemberHeader.pattern):
+    def from_bytes(cls, bytestring, MemberHeader=MemberHeader, Member=Member):
         """
         Parse a SAS XPORT document from a byte string.
         """
@@ -690,14 +696,14 @@ class Library(xport.Library):
         mview = memoryview(bytestring)
         mo = cls.pattern.match(mview)
         if mo is None:
-            lines = [mview[i * 80:(i + 1) * 80] for i in range(8)]
-            LOG.error(f'Document begins with' + '\n%s' * len(lines), *lines)
+            lines = [mview[i * 80:(i + 1) * 80].tobytes() for i in range(8)]
+            LOG.error('Document begins with' + '\n%s' * len(lines), *lines)
             raise ValueError('Document does not match SAS Version 5 or 6 Transport (XPORT) format')
 
-        matches = member_header_re.finditer(mview)
+        matches = MemberHeader.pattern.finditer(mview)
         indices = [m.start(0) for m in matches] + [None]
         chunks = (mview[i:j] for i, j in zip(indices, indices[1:]))
-        self = Library(
+        self = cls(
             members=map(Member.from_bytes, chunks),
             created=strptime(mo['created']),
             modified=strptime(mo['modified']),
@@ -835,7 +841,9 @@ def ieee_to_ibm(ieee):
 
     if ieee == 0.0:
         return b'\x00' * 8
-    if ieee is None or math.isnan(ieee):
+    if math.isnan(ieee):
+        return b'.' + b'\x00' * 7
+    if ieee is None:
         return b'_' + b'\x00' * 7
     if math.isinf(ieee):
         raise NotImplementedError('Cannot convert infinity')
